pub struct Selection {
pub all: File,
pub files: PerFileSelection,
}Expand description
The solc --standard-json output selection.
Fields
all: FileCommon configuration for all files.
files: PerFileSelectionIndividual file selection configuration, required for foundry.
Implementations
Sourceimpl Selection
impl Selection
Sourcepub fn new_all(flags: Vec<Flag>) -> Self
pub fn new_all(flags: Vec<Flag>) -> Self
Creates the selection for all contracts in all files with arbitrary flags.
Sourcepub fn new_required_for_codegen_all() -> Self
pub fn new_required_for_codegen_all() -> Self
Creates the selection required by our compilation process for all contracts in all files.
Sourcepub fn new_required_for_codegen(output_selection: &Self) -> Self
pub fn new_required_for_codegen(output_selection: &Self) -> Self
Creates the selection required by our compilation process for each contract in
output_selection requesting code generation.
Sourcepub fn new_required_for_tests() -> Self
pub fn new_required_for_tests() -> Self
Creates the selection required for test compilation (includes EVM bytecode) for all contracts in all files.
Sourcepub fn new_yul_validation() -> Self
pub fn new_yul_validation() -> Self
Creates the selection required by Yul validation process.
Sourcepub fn extend(&mut self, other: Self) -> &mut Self
pub fn extend(&mut self, other: Self) -> &mut Self
Extends the output selection with another one.
Sourcepub fn selection_to_prune(&self) -> Self
pub fn selection_to_prune(&self) -> Self
Returns flags that were not explicitly requested by the user.
These flags are used to prune JSON output before returning it, removing any output that was automatically added but not requested.