Selection

pub struct Selection {
    pub all: File,
    pub files: PerFileSelection,
}
The solc --standard-json output selection.

Fields

all: File

Common configuration for all files.

files: PerFileSelection

Individual file selection configuration, required for foundry.

Implementations

Source

impl Selection

pub fn new_all(flags: Vec<Flag>) -> Self

Creates the selection for all contracts in all files with arbitrary flags.

pub fn new_required_for_codegen_all() -> Self

Creates the selection required by our compilation process for all contracts in all files.

pub fn new_required_for_codegen(output_selection: &Self) -> Self

Creates the selection required by our compilation process for each contract in output_selection requesting code generation.

pub fn new_required_for_tests() -> Self

Creates the selection required for test compilation (includes EVM bytecode) for all contracts in all files.

pub fn new_yul_validation() -> Self

Creates the selection required by Yul validation process.

pub fn extend(&mut self, other: Self) -> &mut Self

Extends the output selection with another one.

pub fn selection_to_prune(&self) -> Self

Returns flags that were not explicitly requested by the user.

These flags are used to prune JSON output before returning it, removing any output that was automatically added but not requested.

pub fn contains(&self, path: &String, flag: Flag) -> bool

Checks whether the flag is requested.

pub fn retain(&mut self)

Removes unneeded selections.